@@ -1,4 +1,5 @@
 #![cfg_attr(not(debug_assertions), windows_subsystem = "windows")]
+#![feature(const_fn)]
 
 use glium::{
     glutin,
@@ -23,6 +24,7 @@ use background::Background;
 mod vec2;
 use vec2::Vec2;
 mod icon;
+mod image_view;
 
 pub enum UserEvent {
     ImageLoaded(ImageBuffer<Rgba<u16>, Vec<u16>>),
@@ -108,13 +110,6 @@ impl Default for System {
     }
 }
 
-//https://stackoverflow.com/questions/56701736/how-to-correctly-translate-mouse-coords-to-opengl-coords
-fn _cord_to_gl(x: f32, y: f32, width: f32, height: f32) -> (f32, f32) {
-    let x = 2.0 * (x / width) - 1.0;
-    let y = 2.0 * ((y - height + 1.0) / height) - 1.0;
-    (x, y)
-}
-
 impl System {
     pub fn main_loop(self) {
         let System {
@@ -155,13 +150,17 @@ impl System {
                     let size = Vec2::new(dimensions.0 as f32, dimensions.1 as f32);
                     background.render(&mut target, size);
 
+                    if let Some(image) = app.image_view.as_mut() {
+                        image.render(&mut target, size);
+                    }
+
                     platform.prepare_render(&ui, gl_window.window());
                     let draw_data = ui.render();
                     renderer
                         .render(&mut target, draw_data)
                         .expect("Rendering failed");
                     target.finish().expect("Failed to swap buffers");
-                },
+                }
                 Event::WindowEvent {
                     event: WindowEvent::CloseRequested,
                     ..
