@@ -10,7 +10,7 @@ pub struct Vec2<T> {
 }
 
 impl<T: Copy> Vec2<T> {
-    pub fn new(x: T, y: T) -> Self {
+    pub const fn new(x: T, y: T) -> Self {
         Self { inner: [x, y] }
     }
 
@@ -58,7 +58,6 @@ impl<T: Add + Add<Output = T> + Copy> Add for Vec2<T> {
 
     fn add(self, other: Self) -> Self {
         Self {
-            //inner: other.inner,
             inner: [
                 self.inner[0] + other.inner[0],
                 self.inner[1] + other.inner[1],
